@@ -401,7 +401,7 @@ namespace gnote {
 
   void NoteUrlWatcher::initialize ()
   {
-    m_url_tag = NoteTag::Ptr::cast_dynamic(get_note()->get_tag_table()->lookup("link:url"));
+    m_url_tag = get_note()->get_tag_table()->get_url_tag();
   }
 
 
@@ -413,9 +413,8 @@ namespace gnote {
 
   void NoteUrlWatcher::on_note_opened ()
   {
-#if FIXED_GTKSPELL
-    // NOTE: This hack helps avoid multiple URL opens for
-    // cases where the GtkSpell version is fixed to allow
+    // NOTE: This hack helps avoid multiple URL opens
+    // now that Notes always perform
     // TagTable sharing.  This is because if the TagTable is
     // shared, we will connect to the same Tag's event
     // source each time a note is opened, and get called
@@ -426,10 +425,6 @@ namespace gnote {
         sigc::mem_fun(*this, &NoteUrlWatcher::on_url_tag_activated));
       s_text_event_connected = true;
     }
-#else
-    m_url_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteUrlWatcher::on_url_tag_activated));
-#endif
 
     m_click_mark = get_buffer()->create_mark(get_buffer()->begin(), true);
 
@@ -470,7 +465,8 @@ namespace gnote {
     else if (sharp::string_starts_with(url, "~/")) {
       const char * home = getenv("HOME");
       if(home) {
-        url = std::string("file://") + home + sharp::string_substring(url, 2);
+        url = std::string("file://") + home + "/" +
+          sharp::string_substring(url, 2);
       }
     }
     else if (sharp::string_match_iregex(url, 
@@ -519,7 +515,8 @@ namespace gnote {
       // must construct the Glib::ustring from a char *.
       // otherwise it expect the num of chars (UTF-8) instead of bytes.
       // here we compute the index of the URL. It is anchor - start - match.
-      Glib::ustring segment(p, input.data() - p - match1.size());
+      Glib::ustring::size_type len = input.data() - p - match1.size();
+      Glib::ustring segment(p, p + len);
       start_cpy.forward_chars (segment.size());
 
       end = start_cpy;
@@ -642,12 +639,9 @@ namespace gnote {
     m_on_note_renamed_cid = manager().signal_note_renamed.connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_note_renamed));
 
-    m_url_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                           ->get_tag_table()->lookup ("link:url"));
-    m_link_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                            ->get_tag_table()->lookup ("link:internal"));
-    m_broken_link_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                                   ->get_tag_table()->lookup ("link:broken"));
+    m_url_tag = get_note()->get_tag_table()->get_url_tag();
+    m_link_tag = get_note()->get_tag_table()->get_link_tag();
+    m_broken_link_tag = get_note()->get_tag_table()->get_broken_link_tag();
   }
 
 
@@ -661,9 +655,8 @@ namespace gnote {
 
   void NoteLinkWatcher::on_note_opened ()
   {
-#if FIXED_GTKSPELL
-    // NOTE: This avoid multiple link opens for cases where
-    // the GtkSpell version is fixed to allow TagTable
+    // NOTE: This avoid multiple link opens
+    // now that notes always perform TagTable
     // sharing.  This is because if the TagTable is shared,
     // we will connect to the same Tag's event source each
     // time a note is opened, and get called multiple times
@@ -675,12 +668,6 @@ namespace gnote {
         sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
       s_text_event_connected = true;
     }
-#else
-    m_link_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
-    m_broken_link_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
-#endif
     get_buffer()->signal_insert().connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_insert_text));
     get_buffer()->signal_erase().connect(
@@ -949,7 +936,7 @@ namespace gnote {
 
   void NoteWikiWatcher::initialize ()
   {
-    m_broken_link_tag = get_note()->get_tag_table()->lookup ("link:broken");
+    m_broken_link_tag = get_note()->get_tag_table()->get_broken_link_tag();
   }
 
 
@@ -992,30 +979,6 @@ namespace gnote {
     }
   }
 
-  static const char * PATRONYMIC_PREFIXES[] = { 
-    "Mc", 
-    "Mac", 
-    "Le", 
-    "La", 
-    "De", 
-    "Van",
-    NULL
-  };
-
-  bool NoteWikiWatcher::is_patronymic_name (const std::string & word)
-  {
-    const char **prefix = PATRONYMIC_PREFIXES;
-    while(*prefix) {
-      if (sharp::string_starts_with(word, *prefix) &&
-          isupper(word [strlen(*prefix)])) {
-        return true;
-      }
-      prefix++;
-    }
-
-    return false;
-  }
-
   void NoteWikiWatcher::apply_wikiword_to_block (Gtk::TextIter start, Gtk::TextIter end)
   {
     NoteBuffer::get_block_extents (start,
@@ -1033,22 +996,20 @@ namespace gnote {
 
     while(m_regex.FindAndConsume(&input, &match)) {
 
-      if (!is_patronymic_name (match)) {
-      
-        Gtk::TextIter start_cpy = start;
-        Glib::ustring segment(std::string(p, input.data() - p - match.size()));
-        start_cpy.forward_chars (segment.length());
+      Gtk::TextIter start_cpy = start;
+      Glib::ustring::size_type len = input.data() - p - match.size();
+      Glib::ustring segment(p, p + len);
+      start_cpy.forward_chars (segment.length());
 
-        DBG_OUT("Highlighting wikiword: '%s' at offset %d",
-                match.c_str(), segment.length());
+      DBG_OUT("Highlighting wikiword: '%s' at offset %d",
+              match.c_str(), segment.length());
 
-        end = start_cpy;
-        segment = match;
-        end.forward_chars (segment.length());
+      end = start_cpy;
+      segment = match;
+      end.forward_chars (segment.length());
 
-        if (!manager().find(match)) {
-          get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
-        }
+      if (!manager().find(match)) {
+        get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
       }
     }
   }
@@ -1145,8 +1106,9 @@ namespace gnote {
         const Glib::RefPtr<Gtk::TextTag>& tag(*tag_iter);
 
         if (NoteTagTable::tag_is_activatable (tag)) {
-          retval = tag->event (Glib::RefPtr<Gtk::TextView>(get_window()->editor()), 
-                               (GdkEvent*)ev, iter);
+          Glib::RefPtr<Gtk::TextView> editor(get_window()->editor());
+          editor->reference();
+          retval = tag->event (editor, (GdkEvent*)ev, iter);
           if (retval) {
             break;
           }
